from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SensorModulationPerformance(_message.Message):
    __slots__ = ("header", "detection_of_measurement_program", "modulation_id", "distance_range_scaling", "separability_distance", "separability_relative_velocity", "precision_distance", "precision_relative_velocity", "covariance_of_distance_and_relative_velocity", "minimum_measurable_distance", "maximum_measurable_distance", "minimum_measurable_relative_velocity", "maximum_measurable_relative_velocity")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DETECTION_OF_MEASUREMENT_PROGRAM_FIELD_NUMBER: _ClassVar[int]
    MODULATION_ID_FIELD_NUMBER: _ClassVar[int]
    DISTANCE_RANGE_SCALING_FIELD_NUMBER: _ClassVar[int]
    SEPARABILITY_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    SEPARABILITY_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    PRECISION_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    PRECISION_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    COVARIANCE_OF_DISTANCE_AND_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_MEASURABLE_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_MEASURABLE_DISTANCE_FIELD_NUMBER: _ClassVar[int]
    MINIMUM_MEASURABLE_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    MAXIMUM_MEASURABLE_RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    detection_of_measurement_program: int
    modulation_id: int
    distance_range_scaling: float
    separability_distance: float
    separability_relative_velocity: float
    precision_distance: float
    precision_relative_velocity: float
    covariance_of_distance_and_relative_velocity: float
    minimum_measurable_distance: float
    maximum_measurable_distance: float
    minimum_measurable_relative_velocity: float
    maximum_measurable_relative_velocity: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., detection_of_measurement_program: _Optional[int] = ..., modulation_id: _Optional[int] = ..., distance_range_scaling: _Optional[float] = ..., separability_distance: _Optional[float] = ..., separability_relative_velocity: _Optional[float] = ..., precision_distance: _Optional[float] = ..., precision_relative_velocity: _Optional[float] = ..., covariance_of_distance_and_relative_velocity: _Optional[float] = ..., minimum_measurable_distance: _Optional[float] = ..., maximum_measurable_distance: _Optional[float] = ..., minimum_measurable_relative_velocity: _Optional[float] = ..., maximum_measurable_relative_velocity: _Optional[float] = ...) -> None: ...



from make87_messages_ros2.rolling.builtin_interfaces.msg import duration_pb2 as _duration_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.std_msgs.msg import color_rgba_pb2 as _color_rgba_pb2
from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageMarker(_message.Message):
    __slots__ = ("header", "ns", "id", "type", "action", "position", "scale", "outline_color", "filled", "fill_color", "lifetime", "points", "outline_colors")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    NS_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    SCALE_FIELD_NUMBER: _ClassVar[int]
    OUTLINE_COLOR_FIELD_NUMBER: _ClassVar[int]
    FILLED_FIELD_NUMBER: _ClassVar[int]
    FILL_COLOR_FIELD_NUMBER: _ClassVar[int]
    LIFETIME_FIELD_NUMBER: _ClassVar[int]
    POINTS_FIELD_NUMBER: _ClassVar[int]
    OUTLINE_COLORS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ns: str
    id: int
    type: int
    action: int
    position: _point_pb2.Point
    scale: float
    outline_color: _color_rgba_pb2.ColorRGBA
    filled: int
    fill_color: _color_rgba_pb2.ColorRGBA
    lifetime: _duration_pb2.Duration
    points: _containers.RepeatedCompositeFieldContainer[_point_pb2.Point]
    outline_colors: _containers.RepeatedCompositeFieldContainer[_color_rgba_pb2.ColorRGBA]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ns: _Optional[str] = ..., id: _Optional[int] = ..., type: _Optional[int] = ..., action: _Optional[int] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., scale: _Optional[float] = ..., outline_color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., filled: _Optional[int] = ..., fill_color: _Optional[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]] = ..., lifetime: _Optional[_Union[_duration_pb2.Duration, _Mapping]] = ..., points: _Optional[_Iterable[_Union[_point_pb2.Point, _Mapping]]] = ..., outline_colors: _Optional[_Iterable[_Union[_color_rgba_pb2.ColorRGBA, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GimbalManagerCameraTrackRequest(_message.Message):
    __slots__ = ("header", "mode", "x", "y", "radius", "top_left_x", "top_left_y", "bottom_right_x", "bottom_right_y")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    RADIUS_FIELD_NUMBER: _ClassVar[int]
    TOP_LEFT_X_FIELD_NUMBER: _ClassVar[int]
    TOP_LEFT_Y_FIELD_NUMBER: _ClassVar[int]
    BOTTOM_RIGHT_X_FIELD_NUMBER: _ClassVar[int]
    BOTTOM_RIGHT_Y_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    mode: int
    x: float
    y: float
    radius: float
    top_left_x: float
    top_left_y: float
    bottom_right_x: float
    bottom_right_y: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., mode: _Optional[int] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., radius: _Optional[float] = ..., top_left_x: _Optional[float] = ..., top_left_y: _Optional[float] = ..., bottom_right_x: _Optional[float] = ..., bottom_right_y: _Optional[float] = ...) -> None: ...

class GimbalManagerCameraTrackResponse(_message.Message):
    __slots__ = ("header", "success", "result")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    result: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., result: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/moveit_msgs/srv/get_robot_state_from_warehouse.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.moveit_msgs.msg import robot_state_pb2 as make87__messages__ros2_dot_rolling_dot_moveit__msgs_dot_msg_dot_robot__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/moveit_msgs/srv/get_robot_state_from_warehouse.proto\x12,make87_messages_ros2.rolling.moveit_msgs.srv\x1a>make87_messages_ros2/rolling/moveit_msgs/msg/robot_state.proto\"@\n!GetRobotStateFromWarehouseRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05robot\x18\x02 \x01(\t\"m\n\"GetRobotStateFromWarehouseResponse\x12G\n\x05state\x18\x01 \x01(\x0b\x32\x38.make87_messages_ros2.rolling.moveit_msgs.msg.RobotStateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.moveit_msgs.srv.get_robot_state_from_warehouse_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETROBOTSTATEFROMWAREHOUSEREQUEST']._serialized_start=195
  _globals['_GETROBOTSTATEFROMWAREHOUSEREQUEST']._serialized_end=259
  _globals['_GETROBOTSTATEFROMWAREHOUSERESPONSE']._serialized_start=261
  _globals['_GETROBOTSTATEFROMWAREHOUSERESPONSE']._serialized_end=370
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.gazebo_video_monitor_interfaces.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetCameraRequest(_message.Message):
    __slots__ = ("header", "camera_name", "model_name", "link_name", "pose")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAMERA_NAME_FIELD_NUMBER: _ClassVar[int]
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    LINK_NAME_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    camera_name: str
    model_name: str
    link_name: str
    pose: _pose_pb2.Pose
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., camera_name: _Optional[str] = ..., model_name: _Optional[str] = ..., link_name: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ...) -> None: ...

class SetCameraResponse(_message.Message):
    __slots__ = ("header", "message", "success")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    message: str
    success: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., message: _Optional[str] = ..., success: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/cartographer_ros_msgs/srv/start_trajectory.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.cartographer_ros_msgs.msg import status_response_pb2 as make87__messages__ros2_dot_jazzy_dot_cartographer__ros__msgs_dot_msg_dot_status__response__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nKmake87_messages_ros2/jazzy/cartographer_ros_msgs/srv/start_trajectory.proto\x12\x34make87_messages_ros2.jazzy.cartographer_ros_msgs.srv\x1aJmake87_messages_ros2/jazzy/cartographer_ros_msgs/msg/status_response.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\"\xe0\x01\n\x16StartTrajectoryRequest\x12\x1f\n\x17\x63onfiguration_directory\x18\x01 \x01(\t\x12\x1e\n\x16\x63onfiguration_basename\x18\x02 \x01(\t\x12\x18\n\x10use_initial_pose\x18\x03 \x01(\x08\x12H\n\x0cinitial_pose\x18\x04 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12!\n\x19relative_to_trajectory_id\x18\x05 \x01(\x05\"\x86\x01\n\x17StartTrajectoryResponse\x12T\n\x06status\x18\x01 \x01(\x0b\x32\x44.make87_messages_ros2.jazzy.cartographer_ros_msgs.msg.StatusResponse\x12\x15\n\rtrajectory_id\x18\x02 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.cartographer_ros_msgs.srv.start_trajectory_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_STARTTRAJECTORYREQUEST']._serialized_start=267
  _globals['_STARTTRAJECTORYREQUEST']._serialized_end=491
  _globals['_STARTTRAJECTORYRESPONSE']._serialized_start=494
  _globals['_STARTTRAJECTORYRESPONSE']._serialized_end=628
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApplicationOutputs(_message.Message):
    __slots__ = ("header", "evaluation_path_outputs_eval_out", "evaluation_path_outputs_is_safe", "evaluation_path_outputs_is_valid", "monitoring_case_number_outputs", "monitoring_case_number_outputs_flags", "sleep_mode_output", "sleep_mode_output_valid", "error_flag_contamination_warning", "error_flag_contamination_error", "error_flag_manipulation_error", "error_flag_glare", "error_flag_reference_contour_intruded", "error_flag_critical_error", "error_flags_are_valid", "linear_velocity_outputs_velocity_0", "linear_velocity_outputs_velocity_0_valid", "linear_velocity_outputs_velocity_0_transmitted_safely", "linear_velocity_outputs_velocity_1", "linear_velocity_outputs_velocity_1_valid", "linear_velocity_outputs_velocity_1_transmitted_safely", "resulting_velocity", "resulting_velocity_flags")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_PATH_OUTPUTS_EVAL_OUT_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_PATH_OUTPUTS_IS_SAFE_FIELD_NUMBER: _ClassVar[int]
    EVALUATION_PATH_OUTPUTS_IS_VALID_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_NUMBER_OUTPUTS_FIELD_NUMBER: _ClassVar[int]
    MONITORING_CASE_NUMBER_OUTPUTS_FLAGS_FIELD_NUMBER: _ClassVar[int]
    SLEEP_MODE_OUTPUT_FIELD_NUMBER: _ClassVar[int]
    SLEEP_MODE_OUTPUT_VALID_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_CONTAMINATION_WARNING_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_CONTAMINATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_MANIPULATION_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_GLARE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_REFERENCE_CONTOUR_INTRUDED_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAG_CRITICAL_ERROR_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAGS_ARE_VALID_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_0_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_0_VALID_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_0_TRANSMITTED_SAFELY_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_1_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_1_VALID_FIELD_NUMBER: _ClassVar[int]
    LINEAR_VELOCITY_OUTPUTS_VELOCITY_1_TRANSMITTED_SAFELY_FIELD_NUMBER: _ClassVar[int]
    RESULTING_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    RESULTING_VELOCITY_FLAGS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    evaluation_path_outputs_eval_out: _containers.RepeatedScalarFieldContainer[bool]
    evaluation_path_outputs_is_safe: _containers.RepeatedScalarFieldContainer[bool]
    evaluation_path_outputs_is_valid: _containers.RepeatedScalarFieldContainer[bool]
    monitoring_case_number_outputs: _containers.RepeatedScalarFieldContainer[int]
    monitoring_case_number_outputs_flags: _containers.RepeatedScalarFieldContainer[bool]
    sleep_mode_output: int
    sleep_mode_output_valid: bool
    error_flag_contamination_warning: bool
    error_flag_contamination_error: bool
    error_flag_manipulation_error: bool
    error_flag_glare: bool
    error_flag_reference_contour_intruded: bool
    error_flag_critical_error: bool
    error_flags_are_valid: bool
    linear_velocity_outputs_velocity_0: int
    linear_velocity_outputs_velocity_0_valid: bool
    linear_velocity_outputs_velocity_0_transmitted_safely: bool
    linear_velocity_outputs_velocity_1: int
    linear_velocity_outputs_velocity_1_valid: bool
    linear_velocity_outputs_velocity_1_transmitted_safely: bool
    resulting_velocity: _containers.RepeatedScalarFieldContainer[int]
    resulting_velocity_flags: _containers.RepeatedScalarFieldContainer[bool]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., evaluation_path_outputs_eval_out: _Optional[_Iterable[bool]] = ..., evaluation_path_outputs_is_safe: _Optional[_Iterable[bool]] = ..., evaluation_path_outputs_is_valid: _Optional[_Iterable[bool]] = ..., monitoring_case_number_outputs: _Optional[_Iterable[int]] = ..., monitoring_case_number_outputs_flags: _Optional[_Iterable[bool]] = ..., sleep_mode_output: _Optional[int] = ..., sleep_mode_output_valid: bool = ..., error_flag_contamination_warning: bool = ..., error_flag_contamination_error: bool = ..., error_flag_manipulation_error: bool = ..., error_flag_glare: bool = ..., error_flag_reference_contour_intruded: bool = ..., error_flag_critical_error: bool = ..., error_flags_are_valid: bool = ..., linear_velocity_outputs_velocity_0: _Optional[int] = ..., linear_velocity_outputs_velocity_0_valid: bool = ..., linear_velocity_outputs_velocity_0_transmitted_safely: bool = ..., linear_velocity_outputs_velocity_1: _Optional[int] = ..., linear_velocity_outputs_velocity_1_valid: bool = ..., linear_velocity_outputs_velocity_1_transmitted_safely: bool = ..., resulting_velocity: _Optional[_Iterable[int]] = ..., resulting_velocity_flags: _Optional[_Iterable[bool]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/rc_reason_msgs/srv/detect_filling_level.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_jazzy_dot_builtin__interfaces_dot_msg_dot_time__pb2
from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as make87__messages__ros2_dot_jazzy_dot_geometry__msgs_dot_msg_dot_pose__pb2
from make87_messages_ros2.jazzy.rc_common_msgs.msg import return_code_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__common__msgs_dot_msg_dot_return__code__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import grid_size_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_grid__size__pb2
from make87_messages_ros2.jazzy.rc_reason_msgs.msg import load_carrier_with_filling_level_pb2 as make87__messages__ros2_dot_jazzy_dot_rc__reason__msgs_dot_msg_dot_load__carrier__with__filling__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHmake87_messages_ros2/jazzy/rc_reason_msgs/srv/detect_filling_level.proto\x12-make87_messages_ros2.jazzy.rc_reason_msgs.srv\x1a<make87_messages_ros2/jazzy/builtin_interfaces/msg/time.proto\x1a\x37make87_messages_ros2/jazzy/geometry_msgs/msg/pose.proto\x1a?make87_messages_ros2/jazzy/rc_common_msgs/msg/return_code.proto\x1a=make87_messages_ros2/jazzy/rc_reason_msgs/msg/grid_size.proto\x1aSmake87_messages_ros2/jazzy/rc_reason_msgs/msg/load_carrier_with_filling_level.proto\"\xad\x02\n\x19\x44\x65tectFillingLevelRequest\x12\x12\n\npose_frame\x18\x01 \x01(\t\x12\x1d\n\x15region_of_interest_id\x18\x02 \x01(\t\x12 \n\x18region_of_interest_2d_id\x18\x03 \x01(\t\x12\x18\n\x10load_carrier_ids\x18\x04 \x03(\t\x12\x46\n\nrobot_pose\x18\x05 \x01(\x0b\x32\x32.make87_messages_ros2.jazzy.geometry_msgs.msg.Pose\x12Y\n\x18\x66illing_level_cell_count\x18\x06 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.rc_reason_msgs.msg.GridSize\"\x9b\x02\n\x1a\x44\x65tectFillingLevelResponse\x12J\n\ttimestamp\x18\x01 \x01(\x0b\x32\x37.make87_messages_ros2.jazzy.builtin_interfaces.msg.Time\x12\x61\n\rload_carriers\x18\x02 \x03(\x0b\x32J.make87_messages_ros2.jazzy.rc_reason_msgs.msg.LoadCarrierWithFillingLevel\x12N\n\x0breturn_code\x18\x03 \x01(\x0b\x32\x39.make87_messages_ros2.jazzy.rc_common_msgs.msg.ReturnCodeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.rc_reason_msgs.srv.detect_filling_level_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTFILLINGLEVELREQUEST']._serialized_start=456
  _globals['_DETECTFILLINGLEVELREQUEST']._serialized_end=757
  _globals['_DETECTFILLINGLEVELRESPONSE']._serialized_start=760
  _globals['_DETECTFILLINGLEVELRESPONSE']._serialized_end=1043
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class CfgRST(_message.Message):
    __slots__ = ("nav_bbr_mask", "reset_mode", "reserved1")
    NAV_BBR_MASK_FIELD_NUMBER: _ClassVar[int]
    RESET_MODE_FIELD_NUMBER: _ClassVar[int]
    RESERVED1_FIELD_NUMBER: _ClassVar[int]
    nav_bbr_mask: int
    reset_mode: int
    reserved1: int
    def __init__(self, nav_bbr_mask: _Optional[int] = ..., reset_mode: _Optional[int] = ..., reserved1: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Start(_message.Message):
    __slots__ = ("header", "recording_frequency", "ignore_nodes", "ignore_topics", "select_nodes", "select_topics")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RECORDING_FREQUENCY_FIELD_NUMBER: _ClassVar[int]
    IGNORE_NODES_FIELD_NUMBER: _ClassVar[int]
    IGNORE_TOPICS_FIELD_NUMBER: _ClassVar[int]
    SELECT_NODES_FIELD_NUMBER: _ClassVar[int]
    SELECT_TOPICS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    recording_frequency: int
    ignore_nodes: str
    ignore_topics: str
    select_nodes: str
    select_topics: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., recording_frequency: _Optional[int] = ..., ignore_nodes: _Optional[str] = ..., ignore_topics: _Optional[str] = ..., select_nodes: _Optional[str] = ..., select_topics: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import object_classification_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_object__classification__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import shape_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_shape__pb2
from make87_messages_ros2.humble.autoware_perception_msgs.msg import tracked_object_kinematics_pb2 as make87__messages__ros2_dot_humble_dot_autoware__perception__msgs_dot_msg_dot_tracked__object__kinematics__pb2
from make87_messages_ros2.humble.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_humble_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aTmake87_messages_ros2/humble/autoware_perception_msgs/msg/object_classification.proto\x1a\x44make87_messages_ros2/humble/autoware_perception_msgs/msg/shape.proto\x1aXmake87_messages_ros2/humble/autoware_perception_msgs/msg/tracked_object_kinematics.proto\x1a\x41make87_messages_ros2/humble/unique_identifier_msgs/msg/uuid.proto\"\xcc\x03\n\rTrackedObject\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12O\n\tobject_id\x18\x02 \x01(\x0b\x32<.make87_messages_ros2.humble.unique_identifier_msgs.msg.UUID\x12\x1d\n\x15\x65xistence_probability\x18\x03 \x01(\x02\x12\x66\n\x0e\x63lassification\x18\x04 \x03(\x0b\x32N.make87_messages_ros2.humble.autoware_perception_msgs.msg.ObjectClassification\x12\x65\n\nkinematics\x18\x05 \x01(\x0b\x32Q.make87_messages_ros2.humble.autoware_perception_msgs.msg.TrackedObjectKinematics\x12N\n\x05shape\x18\x06 \x01(\x0b\x32?.make87_messages_ros2.humble.autoware_perception_msgs.msg.Shapeb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.tracked_object_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRACKEDOBJECT']._serialized_start=488
  _globals['_TRACKEDOBJECT']._serialized_end=948
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Assignment(_message.Message):
    __slots__ = ("header", "is_assigned", "fleet_name", "expected_robot_name")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IS_ASSIGNED_FIELD_NUMBER: _ClassVar[int]
    FLEET_NAME_FIELD_NUMBER: _ClassVar[int]
    EXPECTED_ROBOT_NAME_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    is_assigned: bool
    fleet_name: str
    expected_robot_name: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., is_assigned: bool = ..., fleet_name: _Optional[str] = ..., expected_robot_name: _Optional[str] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MolaRuntimeParamSetRequest(_message.Message):
    __slots__ = ("parameters",)
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    parameters: str
    def __init__(self, parameters: _Optional[str] = ...) -> None: ...

class MolaRuntimeParamSetResponse(_message.Message):
    __slots__ = ("success", "error_message")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    success: bool
    error_message: str
    def __init__(self, success: bool = ..., error_message: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Accel(_message.Message):
    __slots__ = ("linear", "angular")
    LINEAR_FIELD_NUMBER: _ClassVar[int]
    ANGULAR_FIELD_NUMBER: _ClassVar[int]
    linear: _vector3_pb2.Vector3
    angular: _vector3_pb2.Vector3
    def __init__(self, linear: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., angular: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/rmf_traffic_msgs/msg/itinerary_extend.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.rmf_traffic_msgs.msg import route_pb2 as make87__messages__ros2_dot_humble_dot_rmf__traffic__msgs_dot_msg_dot_route__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/rmf_traffic_msgs/msg/itinerary_extend.proto\x12\x30make87_messages_ros2.humble.rmf_traffic_msgs.msg\x1a!make87_messages/core/header.proto\x1a<make87_messages_ros2/humble/rmf_traffic_msgs/msg/route.proto\"\xb8\x01\n\x0fItineraryExtend\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x13\n\x0bparticipant\x18\x02 \x01(\x04\x12G\n\x06routes\x18\x03 \x03(\x0b\x32\x37.make87_messages_ros2.humble.rmf_traffic_msgs.msg.Route\x12\x19\n\x11itinerary_version\x18\x04 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.rmf_traffic_msgs.msg.itinerary_extend_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ITINERARYEXTEND']._serialized_start=223
  _globals['_ITINERARYEXTEND']._serialized_end=407
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SbgAirDataStatus(_message.Message):
    __slots__ = ("header", "is_delay_time", "pressure_valid", "altitude_valid", "pressure_diff_valid", "air_speed_valid", "air_temperature_valid")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    IS_DELAY_TIME_FIELD_NUMBER: _ClassVar[int]
    PRESSURE_VALID_FIELD_NUMBER: _ClassVar[int]
    ALTITUDE_VALID_FIELD_NUMBER: _ClassVar[int]
    PRESSURE_DIFF_VALID_FIELD_NUMBER: _ClassVar[int]
    AIR_SPEED_VALID_FIELD_NUMBER: _ClassVar[int]
    AIR_TEMPERATURE_VALID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    is_delay_time: bool
    pressure_valid: bool
    altitude_valid: bool
    pressure_diff_valid: bool
    air_speed_valid: bool
    air_temperature_valid: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., is_delay_time: bool = ..., pressure_valid: bool = ..., altitude_valid: bool = ..., pressure_diff_valid: bool = ..., air_speed_valid: bool = ..., air_temperature_valid: bool = ...) -> None: ...



from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import route_pb2 as _route_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ItinerarySet(_message.Message):
    __slots__ = ("participant", "plan", "itinerary", "storage_base", "itinerary_version")
    PARTICIPANT_FIELD_NUMBER: _ClassVar[int]
    PLAN_FIELD_NUMBER: _ClassVar[int]
    ITINERARY_FIELD_NUMBER: _ClassVar[int]
    STORAGE_BASE_FIELD_NUMBER: _ClassVar[int]
    ITINERARY_VERSION_FIELD_NUMBER: _ClassVar[int]
    participant: int
    plan: int
    itinerary: _containers.RepeatedCompositeFieldContainer[_route_pb2.Route]
    storage_base: int
    itinerary_version: int
    def __init__(self, participant: _Optional[int] = ..., plan: _Optional[int] = ..., itinerary: _Optional[_Iterable[_Union[_route_pb2.Route, _Mapping]]] = ..., storage_base: _Optional[int] = ..., itinerary_version: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.ibeo_msgs.msg import contour_point_sigma_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_contour__point__sigma__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_di_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_point2__di__pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_dui_pb2 as make87__messages__ros2_dot_rolling_dot_ibeo__msgs_dot_msg_dot_point2__dui__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCmake87_messages_ros2/rolling/ibeo_msgs/msg/tracked_properties.proto\x12*make87_messages_ros2.rolling.ibeo_msgs.msg\x1a\x44make87_messages_ros2/rolling/ibeo_msgs/msg/contour_point_sigma.proto\x1a:make87_messages_ros2/rolling/ibeo_msgs/msg/point2_di.proto\x1a;make87_messages_ros2/rolling/ibeo_msgs/msg/point2_dui.proto\"\xe9\n\n\x11TrackedProperties\x12\x12\n\nobject_age\x18\x01 \x01(\r\x12\x19\n\x11hidden_status_age\x18\x02 \x01(\r\x12\x14\n\x0cobject_phase\x18\x03 \x01(\r\x12\x18\n\x10\x64ynamic_property\x18\x04 \x01(\r\x12 \n\x18relative_time_of_measure\x18\x05 \x01(\r\x12T\n\x16position_closest_point\x18\x06 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12O\n\x11relative_velocity\x18\x07 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12V\n\x17relative_velocity_sigma\x18\x08 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x16\n\x0e\x63lassification\x18\t \x01(\r\x12\x1a\n\x12\x63lassification_age\x18\n \x01(\r\x12M\n\x0fobject_box_size\x18\x0b \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12T\n\x15object_box_size_sigma\x18\x0c \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x1e\n\x16object_box_orientation\x18\r \x01(\x05\x12$\n\x1cobject_box_orientation_sigma\x18\x0e \x01(\r\x12\x1f\n\x17tracking_point_location\x18\x0f \x01(\r\x12W\n\x19tracking_point_coordinate\x18\x10 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12^\n\x1ftracking_point_coordinate_sigma\x18\x11 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x46\n\x08velocity\x18\x12 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12M\n\x0evelocity_sigma\x18\x13 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12J\n\x0c\x61\x63\x63\x65leration\x18\x14 \x01(\x0b\x32\x34.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Di\x12Q\n\x12\x61\x63\x63\x65leration_sigma\x18\x15 \x01(\x0b\x32\x35.make87_messages_ros2.rolling.ibeo_msgs.msg.Point2Dui\x12\x10\n\x08yaw_rate\x18\x16 \x01(\x05\x12\x16\n\x0eyaw_rate_sigma\x18\x17 \x01(\r\x12 \n\x18number_of_contour_points\x18\x18 \x01(\r\x12Y\n\x12\x63ontour_point_list\x18\x19 \x03(\x0b\x32=.make87_messages_ros2.rolling.ibeo_msgs.msg.ContourPointSigmab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.ibeo_msgs.msg.tracked_properties_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRACKEDPROPERTIES']._serialized_start=307
  _globals['_TRACKEDPROPERTIES']._serialized_end=1692
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/traffic_dependency.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\"\x83\x01\n\x11TrafficDependency\x12\x1c\n\x14\x64\x65pendent_checkpoint\x18\x01 \x01(\x04\x12\x16\n\x0eon_participant\x18\x02 \x01(\x04\x12\x0f\n\x07on_plan\x18\x03 \x01(\x04\x12\x10\n\x08on_route\x18\x04 \x01(\x04\x12\x15\n\ron_checkpoint\x18\x05 \x01(\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.traffic_dependency_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_TRAFFICDEPENDENCY']._serialized_start=130
  _globals['_TRAFFICDEPENDENCY']._serialized_end=261
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Duration(_message.Message):
    __slots__ = ("sec", "nanosec")
    SEC_FIELD_NUMBER: _ClassVar[int]
    NANOSEC_FIELD_NUMBER: _ClassVar[int]
    sec: int
    nanosec: int
    def __init__(self, sec: _Optional[int] = ..., nanosec: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class StatusEvent(_message.Message):
    __slots__ = ("header", "severity", "px4_id", "arguments", "sequence")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SEVERITY_FIELD_NUMBER: _ClassVar[int]
    PX4_ID_FIELD_NUMBER: _ClassVar[int]
    ARGUMENTS_FIELD_NUMBER: _ClassVar[int]
    SEQUENCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    severity: int
    px4_id: int
    arguments: _containers.RepeatedScalarFieldContainer[int]
    sequence: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., severity: _Optional[int] = ..., px4_id: _Optional[int] = ..., arguments: _Optional[_Iterable[int]] = ..., sequence: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import object2225_pb2 as _object2225_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ObjectData2225(_message.Message):
    __slots__ = ("header", "ros2_header", "ibeo_header", "mid_scan_timestamp", "number_of_objects", "object_list")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    MID_SCAN_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    OBJECT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    mid_scan_timestamp: _time_pb2.Time
    number_of_objects: int
    object_list: _containers.RepeatedCompositeFieldContainer[_object2225_pb2.Object2225]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., mid_scan_timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., number_of_objects: _Optional[int] = ..., object_list: _Optional[_Iterable[_Union[_object2225_pb2.Object2225, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.py_trees_ros_interfaces.msg import snapshot_stream_parameters_pb2 as _snapshot_stream_parameters_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ReconfigureSnapshotStreamRequest(_message.Message):
    __slots__ = ("topic_name", "parameters")
    TOPIC_NAME_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    topic_name: str
    parameters: _snapshot_stream_parameters_pb2.SnapshotStreamParameters
    def __init__(self, topic_name: _Optional[str] = ..., parameters: _Optional[_Union[_snapshot_stream_parameters_pb2.SnapshotStreamParameters, _Mapping]] = ...) -> None: ...

class ReconfigureSnapshotStreamResponse(_message.Message):
    __slots__ = ("result",)
    RESULT_FIELD_NUMBER: _ClassVar[int]
    result: bool
    def __init__(self, result: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/autoware_perception_msgs/msg/detected_object_kinematics.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_pose__with__covariance__pb2
from make87_messages_ros2.humble.geometry_msgs.msg import twist_with_covariance_pb2 as make87__messages__ros2_dot_humble_dot_geometry__msgs_dot_msg_dot_twist__with__covariance__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYmake87_messages_ros2/humble/autoware_perception_msgs/msg/detected_object_kinematics.proto\x12\x38make87_messages_ros2.humble.autoware_perception_msgs.msg\x1a!make87_messages/core/header.proto\x1aHmake87_messages_ros2/humble/geometry_msgs/msg/pose_with_covariance.proto\x1aImake87_messages_ros2/humble/geometry_msgs/msg/twist_with_covariance.proto\"\x80\x03\n\x18\x44\x65tectedObjectKinematics\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12_\n\x14pose_with_covariance\x18\x02 \x01(\x0b\x32\x41.make87_messages_ros2.humble.geometry_msgs.msg.PoseWithCovariance\x12\x1f\n\x17has_position_covariance\x18\x03 \x01(\x08\x12 \n\x18orientation_availability\x18\x04 \x01(\r\x12\x61\n\x15twist_with_covariance\x18\x05 \x01(\x0b\x32\x42.make87_messages_ros2.humble.geometry_msgs.msg.TwistWithCovariance\x12\x11\n\thas_twist\x18\x06 \x01(\x08\x12\x1c\n\x14has_twist_covariance\x18\x07 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.autoware_perception_msgs.msg.detected_object_kinematics_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_DETECTEDOBJECTKINEMATICS']._serialized_start=336
  _globals['_DETECTEDOBJECTKINEMATICS']._serialized_end=720
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import ibeo_data_header_pb2 as _ibeo_data_header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HostVehicleState2805(_message.Message):
    __slots__ = ("header", "ros2_header", "ibeo_header", "timestamp", "scan_number", "error_flags", "longitudinal_velocity", "steering_wheel_angle", "front_wheel_angle", "x_position", "y_position", "course_angle", "time_difference", "x_difference", "y_difference", "heading_difference", "current_yaw_rate")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    IBEO_HEADER_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    SCAN_NUMBER_FIELD_NUMBER: _ClassVar[int]
    ERROR_FLAGS_FIELD_NUMBER: _ClassVar[int]
    LONGITUDINAL_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    STEERING_WHEEL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    FRONT_WHEEL_ANGLE_FIELD_NUMBER: _ClassVar[int]
    X_POSITION_FIELD_NUMBER: _ClassVar[int]
    Y_POSITION_FIELD_NUMBER: _ClassVar[int]
    COURSE_ANGLE_FIELD_NUMBER: _ClassVar[int]
    TIME_DIFFERENCE_FIELD_NUMBER: _ClassVar[int]
    X_DIFFERENCE_FIELD_NUMBER: _ClassVar[int]
    Y_DIFFERENCE_FIELD_NUMBER: _ClassVar[int]
    HEADING_DIFFERENCE_FIELD_NUMBER: _ClassVar[int]
    CURRENT_YAW_RATE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    ibeo_header: _ibeo_data_header_pb2.IbeoDataHeader
    timestamp: _time_pb2.Time
    scan_number: int
    error_flags: int
    longitudinal_velocity: float
    steering_wheel_angle: float
    front_wheel_angle: float
    x_position: int
    y_position: int
    course_angle: int
    time_difference: int
    x_difference: int
    y_difference: int
    heading_difference: int
    current_yaw_rate: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., ibeo_header: _Optional[_Union[_ibeo_data_header_pb2.IbeoDataHeader, _Mapping]] = ..., timestamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., scan_number: _Optional[int] = ..., error_flags: _Optional[int] = ..., longitudinal_velocity: _Optional[float] = ..., steering_wheel_angle: _Optional[float] = ..., front_wheel_angle: _Optional[float] = ..., x_position: _Optional[int] = ..., y_position: _Optional[int] = ..., course_angle: _Optional[int] = ..., time_difference: _Optional[int] = ..., x_difference: _Optional[int] = ..., y_difference: _Optional[int] = ..., heading_difference: _Optional[int] = ..., current_yaw_rate: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_information_pb2 as _object_information_pb2
from make87_messages_ros2.humble.object_recognition_msgs.msg import object_type_pb2 as _object_type_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetObjectInformationRequest(_message.Message):
    __slots__ = ("header", "type")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    type: _object_type_pb2.ObjectType
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., type: _Optional[_Union[_object_type_pb2.ObjectType, _Mapping]] = ...) -> None: ...

class GetObjectInformationResponse(_message.Message):
    __slots__ = ("header", "information")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    INFORMATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    information: _object_information_pb2.ObjectInformation
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., information: _Optional[_Union[_object_information_pb2.ObjectInformation, _Mapping]] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class IOOSSDSState(_message.Message):
    __slots__ = ("ossd1a", "ossd1b", "ossd2a", "ossd2b")
    OSSD1A_FIELD_NUMBER: _ClassVar[int]
    OSSD1B_FIELD_NUMBER: _ClassVar[int]
    OSSD2A_FIELD_NUMBER: _ClassVar[int]
    OSSD2B_FIELD_NUMBER: _ClassVar[int]
    ossd1a: int
    ossd1b: int
    ossd2a: int
    ossd2b: int
    def __init__(self, ossd1a: _Optional[int] = ..., ossd1b: _Optional[int] = ..., ossd2a: _Optional[int] = ..., ossd2b: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/play_motion2_msgs/srv/get_motion_info.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages_ros2.humble.play_motion2_msgs.msg import motion_pb2 as make87__messages__ros2_dot_humble_dot_play__motion2__msgs_dot_msg_dot_motion__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGmake87_messages_ros2/humble/play_motion2_msgs/srv/get_motion_info.proto\x12\x31make87_messages_ros2.humble.play_motion2_msgs.srv\x1a!make87_messages/core/header.proto\x1a>make87_messages_ros2/humble/play_motion2_msgs/msg/motion.proto\"X\n\x14GetMotionInfoRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x12\n\nmotion_key\x18\x02 \x01(\t\"\x90\x01\n\x15GetMotionInfoResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12I\n\x06motion\x18\x02 \x01(\x0b\x32\x39.make87_messages_ros2.humble.play_motion2_msgs.msg.Motionb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.play_motion2_msgs.srv.get_motion_info_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETMOTIONINFOREQUEST']._serialized_start=225
  _globals['_GETMOTIONINFOREQUEST']._serialized_end=313
  _globals['_GETMOTIONINFORESPONSE']._serialized_start=316
  _globals['_GETMOTIONINFORESPONSE']._serialized_end=460
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/marti_sensor_msgs/srv/set_exposure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/marti_sensor_msgs/srv/set_exposure.proto\x12\x32make87_messages_ros2.rolling.marti_sensor_msgs.srv\"9\n\x12SetExposureRequest\x12\x15\n\rauto_exposure\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x03\":\n\x13SetExposureResponse\x12\x15\n\rauto_exposure\x18\x01 \x01(\x08\x12\x0c\n\x04time\x18\x02 \x01(\x03\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.marti_sensor_msgs.srv.set_exposure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SETEXPOSUREREQUEST']._serialized_start=125
  _globals['_SETEXPOSUREREQUEST']._serialized_end=182
  _globals['_SETEXPOSURERESPONSE']._serialized_start=184
  _globals['_SETEXPOSURERESPONSE']._serialized_end=242
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from make87_messages_ros2.rolling.webots_ros2_msgs.msg import camera_recognition_object_pb2 as _camera_recognition_object_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class CameraRecognitionObjects(_message.Message):
    __slots__ = ("header", "objects")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    OBJECTS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    objects: _containers.RepeatedCompositeFieldContainer[_camera_recognition_object_pb2.CameraRecognitionObject]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., objects: _Optional[_Iterable[_Union[_camera_recognition_object_pb2.CameraRecognitionObject, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.rc_reason_msgs.msg import rectangle_pb2 as _rectangle_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RangeRectangle(_message.Message):
    __slots__ = ("min_dimensions", "max_dimensions")
    MIN_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    MAX_DIMENSIONS_FIELD_NUMBER: _ClassVar[int]
    min_dimensions: _rectangle_pb2.Rectangle
    max_dimensions: _rectangle_pb2.Rectangle
    def __init__(self, min_dimensions: _Optional[_Union[_rectangle_pb2.Rectangle, _Mapping]] = ..., max_dimensions: _Optional[_Union[_rectangle_pb2.Rectangle, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/nao_sensor_msgs/msg/buttons.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=make87_messages_ros2/humble/nao_sensor_msgs/msg/buttons.proto\x12/make87_messages_ros2.humble.nao_sensor_msgs.msg\x1a!make87_messages/core/header.proto\"\xb8\x01\n\x07\x42uttons\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05\x63hest\x18\x02 \x01(\x08\x12\x1a\n\x12l_foot_bumper_left\x18\x03 \x01(\x08\x12\x1b\n\x13l_foot_bumper_right\x18\x04 \x01(\x08\x12\x1a\n\x12r_foot_bumper_left\x18\x05 \x01(\x08\x12\x1b\n\x13r_foot_bumper_right\x18\x06 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.nao_sensor_msgs.msg.buttons_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_BUTTONS']._serialized_start=150
  _globals['_BUTTONS']._serialized_end=334
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from make87_messages_ros2.humble.ublox_ubx_msgs.msg import esf_sensor_status_pb2 as _esf_sensor_status_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UBXEsfStatus(_message.Message):
    __slots__ = ("header", "ros2_header", "itow", "version", "wt_init_status", "mnt_alg_status", "ins_init_status", "imu_init_status", "fusion_mode", "num_sens", "sensor_statuses")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    ITOW_FIELD_NUMBER: _ClassVar[int]
    VERSION_FIELD_NUMBER: _ClassVar[int]
    WT_INIT_STATUS_FIELD_NUMBER: _ClassVar[int]
    MNT_ALG_STATUS_FIELD_NUMBER: _ClassVar[int]
    INS_INIT_STATUS_FIELD_NUMBER: _ClassVar[int]
    IMU_INIT_STATUS_FIELD_NUMBER: _ClassVar[int]
    FUSION_MODE_FIELD_NUMBER: _ClassVar[int]
    NUM_SENS_FIELD_NUMBER: _ClassVar[int]
    SENSOR_STATUSES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    itow: int
    version: int
    wt_init_status: int
    mnt_alg_status: int
    ins_init_status: int
    imu_init_status: int
    fusion_mode: int
    num_sens: int
    sensor_statuses: _containers.RepeatedCompositeFieldContainer[_esf_sensor_status_pb2.ESFSensorStatus]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., itow: _Optional[int] = ..., version: _Optional[int] = ..., wt_init_status: _Optional[int] = ..., mnt_alg_status: _Optional[int] = ..., ins_init_status: _Optional[int] = ..., imu_init_status: _Optional[int] = ..., fusion_mode: _Optional[int] = ..., num_sens: _Optional[int] = ..., sensor_statuses: _Optional[_Iterable[_Union[_esf_sensor_status_pb2.ESFSensorStatus, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/ur_msgs/msg/robot_state_rt_msg.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/ur_msgs/msg/robot_state_rt_msg.proto\x12&make87_messages_ros2.jazzy.ur_msgs.msg\"\x96\x03\n\x0fRobotStateRTMsg\x12\x0c\n\x04time\x18\x01 \x01(\x01\x12\x10\n\x08q_target\x18\x02 \x03(\x01\x12\x11\n\tqd_target\x18\x03 \x03(\x01\x12\x12\n\nqdd_target\x18\x04 \x03(\x01\x12\x10\n\x08i_target\x18\x05 \x03(\x01\x12\x10\n\x08m_target\x18\x06 \x03(\x01\x12\x10\n\x08q_actual\x18\x07 \x03(\x01\x12\x11\n\tqd_actual\x18\x08 \x03(\x01\x12\x10\n\x08i_actual\x18\t \x03(\x01\x12\x17\n\x0ftool_acc_values\x18\n \x03(\x01\x12\x11\n\ttcp_force\x18\x0b \x03(\x01\x12\x13\n\x0btool_vector\x18\x0c \x03(\x01\x12\x11\n\ttcp_speed\x18\r \x03(\x01\x12\x1a\n\x12\x64igital_input_bits\x18\x0e \x01(\x01\x12\x1a\n\x12motor_temperatures\x18\x0f \x03(\x01\x12\x18\n\x10\x63ontroller_timer\x18\x10 \x01(\x01\x12\x12\n\ntest_value\x18\x11 \x01(\x01\x12\x12\n\nrobot_mode\x18\x12 \x01(\x01\x12\x13\n\x0bjoint_modes\x18\x13 \x03(\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.ur_msgs.msg.robot_state_rt_msg_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_ROBOTSTATERTMSG']._serialized_start=108
  _globals['_ROBOTSTATERTMSG']._serialized_end=514
# @@protoc_insertion_point(module_scope)



from make87_messages_ros2.rolling.ibeo_msgs.msg import contour_point_sigma_pb2 as _contour_point_sigma_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_di_pb2 as _point2_di_pb2
from make87_messages_ros2.rolling.ibeo_msgs.msg import point2_dui_pb2 as _point2_dui_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class UntrackedProperties(_message.Message):
    __slots__ = ("relative_time_of_measurement", "position_closest_point", "object_box_size", "object_box_size_sigma", "object_box_orientation", "object_box_orientation_sigma", "tracking_point_coordinate", "tracking_point_coordinate_sigma", "number_of_contour_points", "contour_point_list")
    RELATIVE_TIME_OF_MEASUREMENT_FIELD_NUMBER: _ClassVar[int]
    POSITION_CLOSEST_POINT_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_SIZE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_SIZE_SIGMA_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_ORIENTATION_SIGMA_FIELD_NUMBER: _ClassVar[int]
    TRACKING_POINT_COORDINATE_FIELD_NUMBER: _ClassVar[int]
    TRACKING_POINT_COORDINATE_SIGMA_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_CONTOUR_POINTS_FIELD_NUMBER: _ClassVar[int]
    CONTOUR_POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    relative_time_of_measurement: int
    position_closest_point: _point2_di_pb2.Point2Di
    object_box_size: _point2_di_pb2.Point2Di
    object_box_size_sigma: _point2_dui_pb2.Point2Dui
    object_box_orientation: int
    object_box_orientation_sigma: int
    tracking_point_coordinate: _point2_di_pb2.Point2Di
    tracking_point_coordinate_sigma: _point2_dui_pb2.Point2Dui
    number_of_contour_points: int
    contour_point_list: _containers.RepeatedCompositeFieldContainer[_contour_point_sigma_pb2.ContourPointSigma]
    def __init__(self, relative_time_of_measurement: _Optional[int] = ..., position_closest_point: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., object_box_size: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., object_box_size_sigma: _Optional[_Union[_point2_dui_pb2.Point2Dui, _Mapping]] = ..., object_box_orientation: _Optional[int] = ..., object_box_orientation_sigma: _Optional[int] = ..., tracking_point_coordinate: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., tracking_point_coordinate_sigma: _Optional[_Union[_point2_dui_pb2.Point2Dui, _Mapping]] = ..., number_of_contour_points: _Optional[int] = ..., contour_point_list: _Optional[_Iterable[_Union[_contour_point_sigma_pb2.ContourPointSigma, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import pose_stamped_pb2 as _pose_stamped_pb2
from make87_messages_ros2.rolling.moveit_msgs.msg import gripper_translation_pb2 as _gripper_translation_pb2
from make87_messages_ros2.rolling.trajectory_msgs.msg import joint_trajectory_pb2 as _joint_trajectory_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class PlaceLocation(_message.Message):
    __slots__ = ("id", "post_place_posture", "place_pose", "quality", "pre_place_approach", "post_place_retreat", "allowed_touch_objects")
    ID_FIELD_NUMBER: _ClassVar[int]
    POST_PLACE_POSTURE_FIELD_NUMBER: _ClassVar[int]
    PLACE_POSE_FIELD_NUMBER: _ClassVar[int]
    QUALITY_FIELD_NUMBER: _ClassVar[int]
    PRE_PLACE_APPROACH_FIELD_NUMBER: _ClassVar[int]
    POST_PLACE_RETREAT_FIELD_NUMBER: _ClassVar[int]
    ALLOWED_TOUCH_OBJECTS_FIELD_NUMBER: _ClassVar[int]
    id: str
    post_place_posture: _joint_trajectory_pb2.JointTrajectory
    place_pose: _pose_stamped_pb2.PoseStamped
    quality: float
    pre_place_approach: _gripper_translation_pb2.GripperTranslation
    post_place_retreat: _gripper_translation_pb2.GripperTranslation
    allowed_touch_objects: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., post_place_posture: _Optional[_Union[_joint_trajectory_pb2.JointTrajectory, _Mapping]] = ..., place_pose: _Optional[_Union[_pose_stamped_pb2.PoseStamped, _Mapping]] = ..., quality: _Optional[float] = ..., pre_place_approach: _Optional[_Union[_gripper_translation_pb2.GripperTranslation, _Mapping]] = ..., post_place_retreat: _Optional[_Union[_gripper_translation_pb2.GripperTranslation, _Mapping]] = ..., allowed_touch_objects: _Optional[_Iterable[str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class MeasurementCycleSyncData(_message.Message):
    __slots__ = ("header", "sync", "sensor_time_offset")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SYNC_FIELD_NUMBER: _ClassVar[int]
    SENSOR_TIME_OFFSET_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    sync: bool
    sensor_time_offset: _time_pb2.Time
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., sync: bool = ..., sensor_time_offset: _Optional[_Union[_time_pb2.Time, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/nao_lola_sensor_msgs/msg/joint_temperatures.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNmake87_messages_ros2/rolling/nao_lola_sensor_msgs/msg/joint_temperatures.proto\x12\x35make87_messages_ros2.rolling.nao_lola_sensor_msgs.msg\")\n\x11JointTemperatures\x12\x14\n\x0ctemperatures\x18\x01 \x03(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.nao_lola_sensor_msgs.msg.joint_temperatures_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_JOINTTEMPERATURES']._serialized_start=137
  _globals['_JOINTTEMPERATURES']._serialized_end=178
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import point2_di_pb2 as _point2_di_pb2
from make87_messages_ros2.humble.ibeo_msgs.msg import size2_d_pb2 as _size2_d_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Object2221(_message.Message):
    __slots__ = ("header", "id", "age", "prediction_age", "relative_timestamp", "reference_point", "reference_point_sigma", "closest_point", "bounding_box_center", "bounding_box_width", "bounding_box_length", "object_box_center", "object_box_size", "object_box_orientation", "absolute_velocity", "absolute_velocity_sigma", "relative_velocity", "classification", "classification_age", "classification_certainty", "number_of_contour_points", "contour_point_list")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    AGE_FIELD_NUMBER: _ClassVar[int]
    PREDICTION_AGE_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_POINT_SIGMA_FIELD_NUMBER: _ClassVar[int]
    CLOSEST_POINT_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_BOX_CENTER_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_BOX_WIDTH_FIELD_NUMBER: _ClassVar[int]
    BOUNDING_BOX_LENGTH_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_CENTER_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_SIZE_FIELD_NUMBER: _ClassVar[int]
    OBJECT_BOX_ORIENTATION_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ABSOLUTE_VELOCITY_SIGMA_FIELD_NUMBER: _ClassVar[int]
    RELATIVE_VELOCITY_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_AGE_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_CERTAINTY_FIELD_NUMBER: _ClassVar[int]
    NUMBER_OF_CONTOUR_POINTS_FIELD_NUMBER: _ClassVar[int]
    CONTOUR_POINT_LIST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    id: int
    age: int
    prediction_age: int
    relative_timestamp: int
    reference_point: _point2_di_pb2.Point2Di
    reference_point_sigma: _point2_di_pb2.Point2Di
    closest_point: _point2_di_pb2.Point2Di
    bounding_box_center: _point2_di_pb2.Point2Di
    bounding_box_width: int
    bounding_box_length: int
    object_box_center: _point2_di_pb2.Point2Di
    object_box_size: _size2_d_pb2.Size2D
    object_box_orientation: int
    absolute_velocity: _point2_di_pb2.Point2Di
    absolute_velocity_sigma: _size2_d_pb2.Size2D
    relative_velocity: _point2_di_pb2.Point2Di
    classification: int
    classification_age: int
    classification_certainty: int
    number_of_contour_points: int
    contour_point_list: _containers.RepeatedCompositeFieldContainer[_point2_di_pb2.Point2Di]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., id: _Optional[int] = ..., age: _Optional[int] = ..., prediction_age: _Optional[int] = ..., relative_timestamp: _Optional[int] = ..., reference_point: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., reference_point_sigma: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., closest_point: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., bounding_box_center: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., bounding_box_width: _Optional[int] = ..., bounding_box_length: _Optional[int] = ..., object_box_center: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., object_box_size: _Optional[_Union[_size2_d_pb2.Size2D, _Mapping]] = ..., object_box_orientation: _Optional[int] = ..., absolute_velocity: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., absolute_velocity_sigma: _Optional[_Union[_size2_d_pb2.Size2D, _Mapping]] = ..., relative_velocity: _Optional[_Union[_point2_di_pb2.Point2Di, _Mapping]] = ..., classification: _Optional[int] = ..., classification_age: _Optional[int] = ..., classification_certainty: _Optional[int] = ..., number_of_contour_points: _Optional[int] = ..., contour_point_list: _Optional[_Iterable[_Union[_point2_di_pb2.Point2Di, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Statistics(_message.Message):
    __slots__ = ("header", "count", "stamp", "tick_duration", "tick_duration_average", "tick_duration_variance", "tick_interval", "tick_interval_average", "tick_interval_variance")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COUNT_FIELD_NUMBER: _ClassVar[int]
    STAMP_FIELD_NUMBER: _ClassVar[int]
    TICK_DURATION_FIELD_NUMBER: _ClassVar[int]
    TICK_DURATION_AVERAGE_FIELD_NUMBER: _ClassVar[int]
    TICK_DURATION_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    TICK_INTERVAL_FIELD_NUMBER: _ClassVar[int]
    TICK_INTERVAL_AVERAGE_FIELD_NUMBER: _ClassVar[int]
    TICK_INTERVAL_VARIANCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    count: int
    stamp: _time_pb2.Time
    tick_duration: float
    tick_duration_average: float
    tick_duration_variance: float
    tick_interval: float
    tick_interval_average: float
    tick_interval_variance: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., count: _Optional[int] = ..., stamp: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., tick_duration: _Optional[float] = ..., tick_duration_average: _Optional[float] = ..., tick_duration_variance: _Optional[float] = ..., tick_interval: _Optional[float] = ..., tick_interval_average: _Optional[float] = ..., tick_interval_variance: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.builtin_interfaces.msg import time_pb2 as _time_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Location(_message.Message):
    __slots__ = ("header", "t", "x", "y", "yaw", "obey_approach_speed_limit", "approach_speed_limit", "level_name", "index")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    T_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    YAW_FIELD_NUMBER: _ClassVar[int]
    OBEY_APPROACH_SPEED_LIMIT_FIELD_NUMBER: _ClassVar[int]
    APPROACH_SPEED_LIMIT_FIELD_NUMBER: _ClassVar[int]
    LEVEL_NAME_FIELD_NUMBER: _ClassVar[int]
    INDEX_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    t: _time_pb2.Time
    x: float
    y: float
    yaw: float
    obey_approach_speed_limit: bool
    approach_speed_limit: float
    level_name: str
    index: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., t: _Optional[_Union[_time_pb2.Time, _Mapping]] = ..., x: _Optional[float] = ..., y: _Optional[float] = ..., yaw: _Optional[float] = ..., obey_approach_speed_limit: bool = ..., approach_speed_limit: _Optional[float] = ..., level_name: _Optional[str] = ..., index: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class VectorInfoGeod(_message.Message):
    __slots__ = ("nr_sv", "error", "mode", "misc", "delta_east", "delta_north", "delta_up", "delta_ve", "delta_vn", "delta_vu", "azimuth", "elevation", "reference_id", "corr_age", "signal_info")
    NR_SV_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    MISC_FIELD_NUMBER: _ClassVar[int]
    DELTA_EAST_FIELD_NUMBER: _ClassVar[int]
    DELTA_NORTH_FIELD_NUMBER: _ClassVar[int]
    DELTA_UP_FIELD_NUMBER: _ClassVar[int]
    DELTA_VE_FIELD_NUMBER: _ClassVar[int]
    DELTA_VN_FIELD_NUMBER: _ClassVar[int]
    DELTA_VU_FIELD_NUMBER: _ClassVar[int]
    AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    ELEVATION_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_ID_FIELD_NUMBER: _ClassVar[int]
    CORR_AGE_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_INFO_FIELD_NUMBER: _ClassVar[int]
    nr_sv: int
    error: int
    mode: int
    misc: int
    delta_east: float
    delta_north: float
    delta_up: float
    delta_ve: float
    delta_vn: float
    delta_vu: float
    azimuth: int
    elevation: int
    reference_id: int
    corr_age: int
    signal_info: int
    def __init__(self, nr_sv: _Optional[int] = ..., error: _Optional[int] = ..., mode: _Optional[int] = ..., misc: _Optional[int] = ..., delta_east: _Optional[float] = ..., delta_north: _Optional[float] = ..., delta_up: _Optional[float] = ..., delta_ve: _Optional[float] = ..., delta_vn: _Optional[float] = ..., delta_vu: _Optional[float] = ..., azimuth: _Optional[int] = ..., elevation: _Optional[int] = ..., reference_id: _Optional[int] = ..., corr_age: _Optional[int] = ..., signal_info: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/lifecycle_msgs/srv/get_state.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.lifecycle_msgs.msg import state_pb2 as make87__messages__ros2_dot_rolling_dot_lifecycle__msgs_dot_msg_dot_state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/rolling/lifecycle_msgs/srv/get_state.proto\x12/make87_messages_ros2.rolling.lifecycle_msgs.srv\x1a;make87_messages_ros2/rolling/lifecycle_msgs/msg/state.proto\"\x11\n\x0fGetStateRequest\"a\n\x10GetStateResponse\x12M\n\rcurrent_state\x18\x01 \x01(\x0b\x32\x36.make87_messages_ros2.rolling.lifecycle_msgs.msg.Stateb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.lifecycle_msgs.srv.get_state_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETSTATEREQUEST']._serialized_start=177
  _globals['_GETSTATEREQUEST']._serialized_end=194
  _globals['_GETSTATERESPONSE']._serialized_start=196
  _globals['_GETSTATERESPONSE']._serialized_end=293
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_event_pb2 as make87__messages__ros2_dot_jazzy_dot_smacc2__msgs_dot_msg_dot_smacc__event__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAmake87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_transition.proto\x12*make87_messages_ros2.jazzy.smacc2_msgs.msg\x1a<make87_messages_ros2/jazzy/smacc2_msgs/msg/smacc_event.proto\"\xe6\x01\n\x0fSmaccTransition\x12\r\n\x05index\x18\x01 \x01(\x05\x12\x17\n\x0ftransition_name\x18\x02 \x01(\t\x12\x17\n\x0ftransition_type\x18\x03 \x01(\t\x12\x1a\n\x12\x64\x65stiny_state_name\x18\x04 \x01(\t\x12\x19\n\x11source_state_name\x18\x05 \x01(\t\x12\x14\n\x0chistory_node\x18\x06 \x01(\x08\x12\x45\n\x05\x65vent\x18\x07 \x01(\x0b\x32\x36.make87_messages_ros2.jazzy.smacc2_msgs.msg.SmaccEventb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.smacc2_msgs.msg.smacc_transition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SMACCTRANSITION']._serialized_start=176
  _globals['_SMACCTRANSITION']._serialized_end=406
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.robot_calibration_msgs.msg import camera_parameter_pb2 as _camera_parameter_pb2
from make87_messages_ros2.humble.sensor_msgs.msg import camera_info_pb2 as _camera_info_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ExtendedCameraInfo(_message.Message):
    __slots__ = ("header", "camera_info", "parameters")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CAMERA_INFO_FIELD_NUMBER: _ClassVar[int]
    PARAMETERS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    camera_info: _camera_info_pb2.CameraInfo
    parameters: _containers.RepeatedCompositeFieldContainer[_camera_parameter_pb2.CameraParameter]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., camera_info: _Optional[_Union[_camera_info_pb2.CameraInfo, _Mapping]] = ..., parameters: _Optional[_Iterable[_Union[_camera_parameter_pb2.CameraParameter, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.jazzy.smacc2_msgs.msg import smacc_state_pb2 as _smacc_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SmaccStateMachine(_message.Message):
    __slots__ = ("states",)
    STATES_FIELD_NUMBER: _ClassVar[int]
    states: _containers.RepeatedCompositeFieldContainer[_smacc_state_pb2.SmaccState]
    def __init__(self, states: _Optional[_Iterable[_Union[_smacc_state_pb2.SmaccState, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GPSStatus(_message.Message):
    __slots__ = ("header", "satellites_used", "satellite_used_prn", "satellites_visible", "satellite_visible_prn", "satellite_visible_z", "satellite_visible_azimuth", "satellite_visible_snr", "status", "motion_source", "orientation_source", "position_source")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_USED_FIELD_NUMBER: _ClassVar[int]
    SATELLITE_USED_PRN_FIELD_NUMBER: _ClassVar[int]
    SATELLITES_VISIBLE_FIELD_NUMBER: _ClassVar[int]
    SATELLITE_VISIBLE_PRN_FIELD_NUMBER: _ClassVar[int]
    SATELLITE_VISIBLE_Z_FIELD_NUMBER: _ClassVar[int]
    SATELLITE_VISIBLE_AZIMUTH_FIELD_NUMBER: _ClassVar[int]
    SATELLITE_VISIBLE_SNR_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MOTION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    ORIENTATION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    POSITION_SOURCE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    satellites_used: int
    satellite_used_prn: _containers.RepeatedScalarFieldContainer[int]
    satellites_visible: int
    satellite_visible_prn: _containers.RepeatedScalarFieldContainer[int]
    satellite_visible_z: _containers.RepeatedScalarFieldContainer[int]
    satellite_visible_azimuth: _containers.RepeatedScalarFieldContainer[int]
    satellite_visible_snr: _containers.RepeatedScalarFieldContainer[int]
    status: int
    motion_source: int
    orientation_source: int
    position_source: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., satellites_used: _Optional[int] = ..., satellite_used_prn: _Optional[_Iterable[int]] = ..., satellites_visible: _Optional[int] = ..., satellite_visible_prn: _Optional[_Iterable[int]] = ..., satellite_visible_z: _Optional[_Iterable[int]] = ..., satellite_visible_azimuth: _Optional[_Iterable[int]] = ..., satellite_visible_snr: _Optional[_Iterable[int]] = ..., status: _Optional[int] = ..., motion_source: _Optional[int] = ..., orientation_source: _Optional[int] = ..., position_source: _Optional[int] = ...) -> None: ...



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class MenuEntry(_message.Message):
    __slots__ = ("id", "parent_id", "title", "command", "command_type")
    ID_FIELD_NUMBER: _ClassVar[int]
    PARENT_ID_FIELD_NUMBER: _ClassVar[int]
    TITLE_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    COMMAND_TYPE_FIELD_NUMBER: _ClassVar[int]
    id: int
    parent_id: int
    title: str
    command: str
    command_type: int
    def __init__(self, id: _Optional[int] = ..., parent_id: _Optional[int] = ..., title: _Optional[str] = ..., command: _Optional[str] = ..., command_type: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_rejection.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import itinerary_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_itinerary__pb2
from make87_messages_ros2.rolling.rmf_traffic_msgs.msg import negotiation_key_pb2 as make87__messages__ros2_dot_rolling_dot_rmf__traffic__msgs_dot_msg_dot_negotiation__key__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_rejection.proto\x12\x31make87_messages_ros2.rolling.rmf_traffic_msgs.msg\x1a\x41make87_messages_ros2/rolling/rmf_traffic_msgs/msg/itinerary.proto\x1aGmake87_messages_ros2/rolling/rmf_traffic_msgs/msg/negotiation_key.proto\"\xeb\x01\n\x14NegotiationRejection\x12\x18\n\x10\x63onflict_version\x18\x01 \x01(\x04\x12P\n\x05table\x18\x02 \x03(\x0b\x32\x41.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.NegotiationKey\x12\x13\n\x0brejected_by\x18\x03 \x01(\x04\x12R\n\x0c\x61lternatives\x18\x04 \x03(\x0b\x32<.make87_messages_ros2.rolling.rmf_traffic_msgs.msg.Itineraryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.rmf_traffic_msgs.msg.negotiation_rejection_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_NEGOTIATIONREJECTION']._serialized_start=273
  _globals['_NEGOTIATIONREJECTION']._serialized_end=508
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/autoware_vehicle_msgs/msg/hazard_lights_report.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.builtin_interfaces.msg import time_pb2 as make87__messages__ros2_dot_rolling_dot_builtin__interfaces_dot_msg_dot_time__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nQmake87_messages_ros2/rolling/autoware_vehicle_msgs/msg/hazard_lights_report.proto\x12\x36make87_messages_ros2.rolling.autoware_vehicle_msgs.msg\x1a>make87_messages_ros2/rolling/builtin_interfaces/msg/time.proto\"n\n\x12HazardLightsReport\x12H\n\x05stamp\x18\x01 \x01(\x0b\x32\x39.make87_messages_ros2.rolling.builtin_interfaces.msg.Time\x12\x0e\n\x06report\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.autoware_vehicle_msgs.msg.hazard_lights_report_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_HAZARDLIGHTSREPORT']._serialized_start=205
  _globals['_HAZARDLIGHTSREPORT']._serialized_end=315
# @@protoc_insertion_point(module_scope)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class Activation(_message.Message):
    __slots__ = ("operation_type", "activator", "activation")
    OPERATION_TYPE_FIELD_NUMBER: _ClassVar[int]
    ACTIVATOR_FIELD_NUMBER: _ClassVar[int]
    ACTIVATION_FIELD_NUMBER: _ClassVar[int]
    operation_type: int
    activator: str
    activation: str
    def __init__(self, operation_type: _Optional[int] = ..., activator: _Optional[str] = ..., activation: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.rolling.lifecycle_msgs.msg import state_pb2 as _state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetAvailableStatesRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class GetAvailableStatesResponse(_message.Message):
    __slots__ = ("available_states",)
    AVAILABLE_STATES_FIELD_NUMBER: _ClassVar[int]
    available_states: _containers.RepeatedCompositeFieldContainer[_state_pb2.State]
    def __init__(self, available_states: _Optional[_Iterable[_Union[_state_pb2.State, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import header_pb2 as _header_pb2_1
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class EsrStatus8(_message.Message):
    __slots__ = ("header", "ros2_header", "canmsg", "history_fault_0", "history_fault_1", "history_fault_2", "history_fault_3", "history_fault_4", "history_fault_5", "history_fault_6", "history_fault_7")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ROS2_HEADER_FIELD_NUMBER: _ClassVar[int]
    CANMSG_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_0_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_1_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_2_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_3_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_4_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_5_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_6_FIELD_NUMBER: _ClassVar[int]
    HISTORY_FAULT_7_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    ros2_header: _header_pb2_1.Header
    canmsg: str
    history_fault_0: int
    history_fault_1: int
    history_fault_2: int
    history_fault_3: int
    history_fault_4: int
    history_fault_5: int
    history_fault_6: int
    history_fault_7: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., ros2_header: _Optional[_Union[_header_pb2_1.Header, _Mapping]] = ..., canmsg: _Optional[str] = ..., history_fault_0: _Optional[int] = ..., history_fault_1: _Optional[int] = ..., history_fault_2: _Optional[int] = ..., history_fault_3: _Optional[int] = ..., history_fault_4: _Optional[int] = ..., history_fault_5: _Optional[int] = ..., history_fault_6: _Optional[int] = ..., history_fault_7: _Optional[int] = ...) -> None: ...



from make87_messages_ros2.rolling.geometry_msgs.msg import point_pb2 as _point_pb2
from make87_messages_ros2.rolling.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as _uuid_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RadarTrack(_message.Message):
    __slots__ = ("uuid", "position", "velocity", "acceleration", "size", "classification", "position_covariance", "velocity_covariance", "acceleration_covariance", "size_covariance")
    UUID_FIELD_NUMBER: _ClassVar[int]
    POSITION_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_FIELD_NUMBER: _ClassVar[int]
    SIZE_FIELD_NUMBER: _ClassVar[int]
    CLASSIFICATION_FIELD_NUMBER: _ClassVar[int]
    POSITION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    VELOCITY_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    ACCELERATION_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    SIZE_COVARIANCE_FIELD_NUMBER: _ClassVar[int]
    uuid: _uuid_pb2.UUID
    position: _point_pb2.Point
    velocity: _vector3_pb2.Vector3
    acceleration: _vector3_pb2.Vector3
    size: _vector3_pb2.Vector3
    classification: int
    position_covariance: _containers.RepeatedScalarFieldContainer[float]
    velocity_covariance: _containers.RepeatedScalarFieldContainer[float]
    acceleration_covariance: _containers.RepeatedScalarFieldContainer[float]
    size_covariance: _containers.RepeatedScalarFieldContainer[float]
    def __init__(self, uuid: _Optional[_Union[_uuid_pb2.UUID, _Mapping]] = ..., position: _Optional[_Union[_point_pb2.Point, _Mapping]] = ..., velocity: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., acceleration: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., size: _Optional[_Union[_vector3_pb2.Vector3, _Mapping]] = ..., classification: _Optional[int] = ..., position_covariance: _Optional[_Iterable[float]] = ..., velocity_covariance: _Optional[_Iterable[float]] = ..., acceleration_covariance: _Optional[_Iterable[float]] = ..., size_covariance: _Optional[_Iterable[float]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SaveMapRequest(_message.Message):
    __slots__ = ("header", "map_topic", "map_url", "image_format", "map_mode", "free_thresh", "occupied_thresh")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    MAP_TOPIC_FIELD_NUMBER: _ClassVar[int]
    MAP_URL_FIELD_NUMBER: _ClassVar[int]
    IMAGE_FORMAT_FIELD_NUMBER: _ClassVar[int]
    MAP_MODE_FIELD_NUMBER: _ClassVar[int]
    FREE_THRESH_FIELD_NUMBER: _ClassVar[int]
    OCCUPIED_THRESH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    map_topic: str
    map_url: str
    image_format: str
    map_mode: str
    free_thresh: float
    occupied_thresh: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., map_topic: _Optional[str] = ..., map_url: _Optional[str] = ..., image_format: _Optional[str] = ..., map_mode: _Optional[str] = ..., free_thresh: _Optional[float] = ..., occupied_thresh: _Optional[float] = ...) -> None: ...

class SaveMapResponse(_message.Message):
    __slots__ = ("header", "result")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RESULT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    result: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., result: bool = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/mobileye_560_660_msgs/msg/lane.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?make87_messages_ros2/jazzy/mobileye_560_660_msgs/msg/lane.proto\x12\x34make87_messages_ros2.jazzy.mobileye_560_660_msgs.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xf7\x01\n\x04Lane\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x16\n\x0elane_curvature\x18\x02 \x01(\x01\x12\x14\n\x0clane_heading\x18\x03 \x01(\x01\x12\x19\n\x11\x63onstruction_area\x18\x04 \x01(\x08\x12\x13\n\x0bpitch_angle\x18\x05 \x01(\x01\x12\x11\n\tyaw_angle\x18\x06 \x01(\x01\x12\x1e\n\x16right_ldw_availability\x18\x07 \x01(\x08\x12\x1d\n\x15left_ldw_availability\x18\x08 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.mobileye_560_660_msgs.msg.lane_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_LANE']._serialized_start=176
  _globals['_LANE']._serialized_end=423
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.std_msgs.msg import empty_pb2 as _empty_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ClearProblemKnowledgeRequest(_message.Message):
    __slots__ = ("header", "request")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    REQUEST_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    request: _empty_pb2.Empty
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., request: _Optional[_Union[_empty_pb2.Empty, _Mapping]] = ...) -> None: ...

class ClearProblemKnowledgeResponse(_message.Message):
    __slots__ = ("header", "success", "error_info")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    error_info: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., error_info: _Optional[str] = ...) -> None: ...



from make87_messages_ros2.jazzy.geometry_msgs.msg import pose_pb2 as _pose_pb2
from make87_messages_ros2.jazzy.marti_common_msgs.msg import key_value_pb2 as _key_value_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RoutePoint(_message.Message):
    __slots__ = ("pose", "id", "properties")
    POSE_FIELD_NUMBER: _ClassVar[int]
    ID_FIELD_NUMBER: _ClassVar[int]
    PROPERTIES_FIELD_NUMBER: _ClassVar[int]
    pose: _pose_pb2.Pose
    id: str
    properties: _containers.RepeatedCompositeFieldContainer[_key_value_pb2.KeyValue]
    def __init__(self, pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., id: _Optional[str] = ..., properties: _Optional[_Iterable[_Union[_key_value_pb2.KeyValue, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/jazzy/sbg_driver/msg/sbg_event.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.jazzy.std_msgs.msg import header_pb2 as make87__messages__ros2_dot_jazzy_dot_std__msgs_dot_msg_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n9make87_messages_ros2/jazzy/sbg_driver/msg/sbg_event.proto\x12)make87_messages_ros2.jazzy.sbg_driver.msg\x1a\x34make87_messages_ros2/jazzy/std_msgs/msg/header.proto\"\xad\x02\n\x08SbgEvent\x12?\n\x06header\x18\x01 \x01(\x0b\x32/.make87_messages_ros2.jazzy.std_msgs.msg.Header\x12\x12\n\ntime_stamp\x18\x02 \x01(\r\x12\x10\n\x08overflow\x18\x03 \x01(\x08\x12\x16\n\x0eoffset_0_valid\x18\x04 \x01(\x08\x12\x16\n\x0eoffset_1_valid\x18\x05 \x01(\x08\x12\x16\n\x0eoffset_2_valid\x18\x06 \x01(\x08\x12\x16\n\x0eoffset_3_valid\x18\x07 \x01(\x08\x12\x15\n\rtime_offset_0\x18\x08 \x01(\r\x12\x15\n\rtime_offset_1\x18\t \x01(\r\x12\x15\n\rtime_offset_2\x18\n \x01(\r\x12\x15\n\rtime_offset_3\x18\x0b \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.jazzy.sbg_driver.msg.sbg_event_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_SBGEVENT']._serialized_start=159
  _globals['_SBGEVENT']._serialized_end=460
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.rc_common_msgs.msg import return_code_pb2 as _return_code_pb2
from make87_messages_ros2.humble.rc_reason_msgs.msg import load_carrier_model_pb2 as _load_carrier_model_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetLoadCarriersRequest(_message.Message):
    __slots__ = ("header", "load_carrier_ids")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIER_IDS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    load_carrier_ids: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., load_carrier_ids: _Optional[_Iterable[str]] = ...) -> None: ...

class GetLoadCarriersResponse(_message.Message):
    __slots__ = ("header", "load_carriers", "return_code")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LOAD_CARRIERS_FIELD_NUMBER: _ClassVar[int]
    RETURN_CODE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    load_carriers: _containers.RepeatedCompositeFieldContainer[_load_carrier_model_pb2.LoadCarrierModel]
    return_code: _return_code_pb2.ReturnCode
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., load_carriers: _Optional[_Iterable[_Union[_load_carrier_model_pb2.LoadCarrierModel, _Mapping]]] = ..., return_code: _Optional[_Union[_return_code_pb2.ReturnCode, _Mapping]] = ...) -> None: ...



from make87_messages_ros2.rolling.std_msgs.msg import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AnsWriteParaset(_message.Message):
    __slots__ = ("header", "command", "paramset_cksum_low_byte", "paramset_cksum_high_byte")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COMMAND_FIELD_NUMBER: _ClassVar[int]
    PARAMSET_CKSUM_LOW_BYTE_FIELD_NUMBER: _ClassVar[int]
    PARAMSET_CKSUM_HIGH_BYTE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    command: int
    paramset_cksum_low_byte: int
    paramset_cksum_high_byte: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., command: _Optional[int] = ..., paramset_cksum_low_byte: _Optional[int] = ..., paramset_cksum_high_byte: _Optional[int] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/rolling/geographic_msgs/srv/get_route_plan.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages_ros2.rolling.geographic_msgs.msg import route_path_pb2 as make87__messages__ros2_dot_rolling_dot_geographic__msgs_dot_msg_dot_route__path__pb2
from make87_messages_ros2.rolling.unique_identifier_msgs.msg import uuid_pb2 as make87__messages__ros2_dot_rolling_dot_unique__identifier__msgs_dot_msg_dot_uuid__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEmake87_messages_ros2/rolling/geographic_msgs/srv/get_route_plan.proto\x12\x30make87_messages_ros2.rolling.geographic_msgs.srv\x1a\x41make87_messages_ros2/rolling/geographic_msgs/msg/route_path.proto\x1a\x42make87_messages_ros2/rolling/unique_identifier_msgs/msg/uuid.proto\"\x80\x02\n\x13GetRoutePlanRequest\x12N\n\x07network\x18\x01 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12L\n\x05start\x18\x02 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\x12K\n\x04goal\x18\x03 \x01(\x0b\x32=.make87_messages_ros2.rolling.unique_identifier_msgs.msg.UUID\"\x82\x01\n\x14GetRoutePlanResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x0e\n\x06status\x18\x02 \x01(\t\x12I\n\x04plan\x18\x03 \x01(\x0b\x32;.make87_messages_ros2.rolling.geographic_msgs.msg.RoutePathb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.rolling.geographic_msgs.srv.get_route_plan_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GETROUTEPLANREQUEST']._serialized_start=259
  _globals['_GETROUTEPLANREQUEST']._serialized_end=515
  _globals['_GETROUTEPLANRESPONSE']._serialized_start=518
  _globals['_GETROUTEPLANRESPONSE']._serialized_end=648
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_configure.proto
# Protobuf Python Version: 4.25.6
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJmake87_messages_ros2/humble/mavros_msgs/srv/gimbal_manager_configure.proto\x12+make87_messages_ros2.humble.mavros_msgs.srv\x1a!make87_messages/core/header.proto\"\xc9\x01\n\x1dGimbalManagerConfigureRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x15\n\rsysid_primary\x18\x02 \x01(\x05\x12\x16\n\x0e\x63ompid_primary\x18\x03 \x01(\x05\x12\x17\n\x0fsysid_secondary\x18\x04 \x01(\x05\x12\x18\n\x10\x63ompid_secondary\x18\x05 \x01(\x05\x12\x18\n\x10gimbal_device_id\x18\x06 \x01(\r\"o\n\x1eGimbalManagerConfigureResponse\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0f\n\x07success\x18\x02 \x01(\x08\x12\x0e\n\x06result\x18\x03 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages_ros2.humble.mavros_msgs.srv.gimbal_manager_configure_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_GIMBALMANAGERCONFIGUREREQUEST']._serialized_start=159
  _globals['_GIMBALMANAGERCONFIGUREREQUEST']._serialized_end=360
  _globals['_GIMBALMANAGERCONFIGURERESPONSE']._serialized_start=362
  _globals['_GIMBALMANAGERCONFIGURERESPONSE']._serialized_end=473
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import vector3_pb2 as _vector3_pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import entity_pb2 as _entity_pb2
from make87_messages_ros2.humble.ros_gz_interfaces.msg import joint_wrench_pb2 as _joint_wrench_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Contact(_message.Message):
    __slots__ = ("header", "collision1", "collision2", "positions", "normals", "depths", "wrenches")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    COLLISION1_FIELD_NUMBER: _ClassVar[int]
    COLLISION2_FIELD_NUMBER: _ClassVar[int]
    POSITIONS_FIELD_NUMBER: _ClassVar[int]
    NORMALS_FIELD_NUMBER: _ClassVar[int]
    DEPTHS_FIELD_NUMBER: _ClassVar[int]
    WRENCHES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    collision1: _entity_pb2.Entity
    collision2: _entity_pb2.Entity
    positions: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    normals: _containers.RepeatedCompositeFieldContainer[_vector3_pb2.Vector3]
    depths: _containers.RepeatedScalarFieldContainer[float]
    wrenches: _containers.RepeatedCompositeFieldContainer[_joint_wrench_pb2.JointWrench]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., collision1: _Optional[_Union[_entity_pb2.Entity, _Mapping]] = ..., collision2: _Optional[_Union[_entity_pb2.Entity, _Mapping]] = ..., positions: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., normals: _Optional[_Iterable[_Union[_vector3_pb2.Vector3, _Mapping]]] = ..., depths: _Optional[_Iterable[float]] = ..., wrenches: _Optional[_Iterable[_Union[_joint_wrench_pb2.JointWrench, _Mapping]]] = ...) -> None: ...



from make87_messages_ros2.rolling.action_msgs.msg import goal_info_pb2 as _goal_info_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GoalStatus(_message.Message):
    __slots__ = ("goal_info", "status")
    GOAL_INFO_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    goal_info: _goal_info_pb2.GoalInfo
    status: int
    def __init__(self, goal_info: _Optional[_Union[_goal_info_pb2.GoalInfo, _Mapping]] = ..., status: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages_ros2.humble.geometry_msgs.msg import pose_pb2 as _pose_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class HandEyeCalibrationRequest(_message.Message):
    __slots__ = ("header",)
    HEADER_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ...) -> None: ...

class HandEyeCalibrationResponse(_message.Message):
    __slots__ = ("header", "success", "status", "message", "pose", "error", "translation_error_meter", "rotation_error_degree", "robot_mounted")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    POSE_FIELD_NUMBER: _ClassVar[int]
    ERROR_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_ERROR_METER_FIELD_NUMBER: _ClassVar[int]
    ROTATION_ERROR_DEGREE_FIELD_NUMBER: _ClassVar[int]
    ROBOT_MOUNTED_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    success: bool
    status: int
    message: str
    pose: _pose_pb2.Pose
    error: float
    translation_error_meter: float
    rotation_error_degree: float
    robot_mounted: bool
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., success: bool = ..., status: _Optional[int] = ..., message: _Optional[str] = ..., pose: _Optional[_Union[_pose_pb2.Pose, _Mapping]] = ..., error: _Optional[float] = ..., translation_error_meter: _Optional[float] = ..., rotation_error_degree: _Optional[float] = ..., robot_mounted: bool = ...) -> None: ...



from make87_messages_ros2.jazzy.ur_msgs.msg import analog_pb2 as _analog_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class SetAnalogOutputRequest(_message.Message):
    __slots__ = ("data",)
    DATA_FIELD_NUMBER: _ClassVar[int]
    data: _analog_pb2.Analog
    def __init__(self, data: _Optional[_Union[_analog_pb2.Analog, _Mapping]] = ...) -> None: ...

class SetAnalogOutputResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: bool = ...) -> None: ...
